@@ -861,7 +861,7 @@ class Client:
         :type output: Optional[dict]
         :param error: Error from the execution, required when status is 'failed', needs to contain 'message'
         :type error: Optional[dict]
-        :param start_time: Utc start time that will replace the original start time of the execution
+        :param start_time: start time that will replace the original start time of the execution
         :type start_time: Optional[str]
         :return: Transition execution response from REST API
         :rtype: dict
@@ -869,12 +869,17 @@ class Client:
         :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
  :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
         """
+        if isinstance(start_time, datetime):
+            if not start_time.tzinfo:
+                start_time = start_time.astimezone()
+            start_time = start_time.isoformat()
+
         url = f'/transitions/{transition_id}/executions/{execution_id}'
         body = {
             'status': status,
             'output': output,
             'error': error,
-            'startTime': f'{start_time}' if start_time else None,
+            'startTime': start_time,
         }
         return self._make_request(requests.patch, url, body=dictstrip(body))
 
@@ -1004,7 +1009,14 @@ class Client:
         """
         return self._make_request(requests.delete, f'/users/{user_id}')
 
-    def create_workflow(self, specification: dict, *, error_config: Optional[dict] = None, **optional_args) -> Dict:
+    def create_workflow(
+        self,
+        specification: dict,
+        *,
+        error_config: Optional[dict] = None,
+        completed_config: Optional[dict] = None,
+        **optional_args,
+    ) -> Dict:
         """Creates a new workflow, calls the POST /workflows endpoint.
         Check out Lucidtech's tutorials for more info on how to create a workflow.
 
@@ -1024,6 +1036,8 @@ class Client:
         :type description: Optional[str]
         :param error_config: Configuration of error handler
         :type error_config: Optional[dict]
+        :param completed_config: Configuration of a job to run whenever a workflow execution ends
+        :type completed_config: Optional[dict]
         :return: Workflow response from REST API
         :rtype: dict
 
@@ -1033,6 +1047,7 @@ class Client:
         body = dictstrip({
             'specification': specification,
             'errorConfig': error_config,
+            'completedConfig': completed_config,
         })
         body.update(**optional_args)
 
@@ -1184,6 +1199,58 @@ class Client:
         }
         return self._make_request(requests.get, url, params=params)
 
+    def get_workflow_execution(self, workflow_id: str, execution_id: str) -> Dict:
+        """Get a workflow execution, calls the GET /workflows/{workflow_id}/executions/{execution_id} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.get_workflow_execution('<workflow_id>', '<execution_id>')
+
+        :param workflow_id: Id of the workflow that performs the execution
+        :type workflow_id: str
+        :param execution_id: Id of the execution to get
+        :type execution_id: str
+        :return: Workflow execution response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        url = f'/workflows/{workflow_id}/executions/{execution_id}'
+        return self._make_request(requests.get, url)
+
+    def update_workflow_execution(
+        self,
+        workflow_id: str,
+        execution_id: str,
+        next_transition_id: str,
+    ) -> Dict:
+        """Retry or end the processing of a workflow execution,
+        calls the PATCH /workflows/{workflow_id}/executions/{execution_id} endpoint.
+
+        >>> from las.client import Client
+        >>> client = Client()
+        >>> client.update_workflow_execution('<workflow_id>', '<execution_id>', '<next_transition_id>')
+
+        :param workflow_id: Id of the workflow that performs the execution
+        :type workflow_id: str
+        :param execution_id: Id of the execution to update
+        :type execution_id: str
+        :param next_transition_id: the next transition to transition into, to end the workflow-execution,
+        use: las:transition:commons-failed
+        :type next_transition_id: str
+        :return: Workflow execution response from REST API
+        :rtype: dict
+
+        :raises: :py:class:`~las.InvalidCredentialsException`, :py:class:`~las.TooManyRequestsException`,\
+ :py:class:`~las.LimitExceededException`, :py:class:`requests.exception.RequestException`
+        """
+        url = f'/workflows/{workflow_id}/executions/{execution_id}'
+        body = {
+            'nextTransitionId': next_transition_id,
+        }
+        return self._make_request(requests.patch, url, body=dictstrip(body))
+
     def delete_workflow_execution(self, workflow_id: str, execution_id: str) -> Dict:
         """Deletes the execution with the provided execution_id from workflow_id,
         calls the DELETE /workflows/{workflowId}/executions/{executionId} endpoint.
